@@ -175,7 +175,7 @@ static void _connection_init(MafwGstRenderer *renderer);
  * Registers the plugin descriptor making this plugin available to the
  * framework and applications
  */
-G_MODULE_EXPORT MafwPluginDescriptor mafw_gst_renderer_plugin_description = {
+G_MODULE_EXPORT MafwPluginDescriptor mafw_gst_subtitles_renderer_plugin_description = {
 	{ .name		= MAFW_GST_RENDERER_PLUGIN_NAME },
 	.initialize	= mafw_gst_renderer_initialize,
 	.deinitialize	= mafw_gst_renderer_deinitialize,
@@ -208,9 +208,8 @@ static void mafw_gst_renderer_class_init(MafwGstRendererClass *klass)
 	GObjectClass *gclass = NULL;
 	MafwRendererClass *renderer_class = NULL;
 	const gchar *preloaded_plugins[] = {"playback", "uridecodebin",
-		"coreelements", "typefindfunctions", "omx", "selector",
-		"autodetect", "pulseaudio", "audioconvert", "audioresample",
-		"xvimagesink", "ffmpegcolorspace", "videoscale", NULL};
+				"coreelements", "typefindfunctions", "dsp",
+				"pulseaudio", "xvimagesink", NULL};
 	gint i = 0;
 	GObject *plugin;
 
@@ -284,7 +283,9 @@ static void mafw_gst_renderer_init(MafwGstRenderer *self)
 	g_return_if_fail(renderer != NULL);
 
 	mafw_extension_add_property(MAFW_EXTENSION(self), "volume", G_TYPE_UINT);
+#ifdef MAFW_GST_RENDERER_ENABLE_MUTE
 	mafw_extension_add_property(MAFW_EXTENSION(self), "mute", G_TYPE_BOOLEAN);
+#endif
 	mafw_extension_add_property(MAFW_EXTENSION(self), "xid", G_TYPE_UINT);
 	mafw_extension_add_property(MAFW_EXTENSION(self), "error-policy", G_TYPE_UINT);
 	MAFW_EXTENSION_SUPPORTS_AUTOPAINT(self);
@@ -2295,6 +2296,11 @@ static void mafw_gst_renderer_set_property(MafwExtension *self,
 			renderer->worker,
 			g_value_get_boolean(value));
 	}
+	else if (!strcmp(key, MAFW_PROPERTY_RENDERER_COLORKEY)) {
+		mafw_gst_renderer_worker_set_colorkey(
+			renderer->worker,
+			g_value_get_int(value));
+	}
 #ifdef HAVE_GDKPIXBUF
 	else if (!strcmp(key,
 			 MAFW_PROPERTY_GST_RENDERER_CURRENT_FRAME_ON_PAUSE)) {
